@@ -1,4 +1,3 @@
-import json
 try:
     from collections import OrderedDict
 except ImportError:
@@ -8,17 +7,13 @@ from django.core.urlresolvers import reverse
 from modeltree.tree import MODELTREE_DEFAULT_ALIAS, trees
 from avocado.query import pipeline
 from avocado.export import HTMLExporter
-from restlib2.params import Parametizer, param_cleaners
-from .base import BaseResource, PaginatorResource, PaginatorParametizer
+from restlib2.params import StrParam
+from .base import BaseResource
+from .pagination import PaginatorResource, PaginatorParametizer
 
 
 class PreviewParametizer(PaginatorParametizer):
-    tree = MODELTREE_DEFAULT_ALIAS
-
-    def clean_tree(self, value):
-        if value not in trees:
-            return MODELTREE_DEFAULT_ALIAS
-        return value
+    tree = StrParam(MODELTREE_DEFAULT_ALIAS, choices=trees)
 
 
 class PreviewResource(BaseResource, PaginatorResource):
@@ -35,7 +30,7 @@ class PreviewResource(BaseResource, PaginatorResource):
         params = self.get_params(request)
 
         page = params.get('page')
-        per_page = params.get('per_page')
+        limit = params.get('limit')
         tree = params.get('tree')
 
         # Get the request's view and context
@@ -50,12 +45,12 @@ class PreviewResource(BaseResource, PaginatorResource):
         queryset = processor.get_queryset(request=request)
 
         # Get paginator and page
-        paginator = self.get_paginator(queryset, per_page)
+        paginator = self.get_paginator(queryset, limit=limit)
         page = paginator.page(page)
         offset = max(0, page.start_index() - 1)
 
         # Prepare the exporter and iterable
-        iterable = processor.get_iterable(offset=offset, limit=per_page)
+        iterable = processor.get_iterable(offset=offset, limit=limit)
 
         # Build up the header keys.
         # TODO: This is flawed since it assumes the output columns
@@ -102,7 +97,7 @@ class PreviewResource(BaseResource, PaginatorResource):
             'object_name': model_name,
             'object_name_plural': model_name_plural,
             'object_count': paginator.count,
-            'per_page': paginator.per_page,
+            'limit': paginator.per_page,
             'num_pages': paginator.num_pages,
             'page_num': page.number,
             '_links': links,
@@ -116,6 +111,4 @@ class PreviewResource(BaseResource, PaginatorResource):
 preview_resource = PreviewResource()
 
 # Resource endpoints
-urlpatterns = patterns('',
-    url(r'^$', preview_resource, name='preview'),
-)
+urlpatterns = patterns('', url(r'^$', preview_resource, name='preview'), )
